Django Grappelli Documentation — Django Grappelli v1.3 documentation

### Navigation

- index
- next |
- Django Grappelli v1.3 documentation »

# Django Grappelli Documentation

This documentation covers version 1.3 of Grappelli. Grappelli is a grid-based alternative/extension to the Django administration interface.

Note

This is a preliminary version of the Grappelli Documentation.

Contents

- Quick start guide
  - Download
  - Installation
- Customization
  - Available Settings
  - Collapsibles
  - Inline Sortables
  - Related Lookups
  - Generic Relationships
  - Using TinyMCE

Dashboard

- Dashboard Setup
  - Add `grappelli.dashboard` to your Installed Apps
  - Create a custom Dashboard
  - Create custom Dashboards for multiple admin sites
- Dashboard API
  - The `Dashboard` class
  - The `DashboardModule` class
  - The `Group` class
  - The `LinkList` class
  - The `AppList` class
  - The `ModelList` class
  - The `RecentActions` class
  - The `Feed` class
- Dashboard Layout
- Extending the Dashboard

Internals

- Templates
- Javascripts
  - Original JS
  - Grappelli JS

Help

- FAQ
- Third Party Applications
- Troubleshooting
- Django Issues
- Grappelli 1.3 Release Notes

### Navigation

- index
- next |
- Django Grappelli v1.3 documentation »